@@ -14,11 +14,11 @@ String::Copyright - Representation of text-based copyright statements
 
 =head1 VERSION
 
-Version 0.002001
+Version 0.003000
 
 =cut
 
-our $VERSION = '0.002001';
+our $VERSION = '0.003000';
 
 # Dependencies
 use parent 'Exporter::Tiny';
@@ -29,15 +29,11 @@ our @EXPORT = qw/copyright/;
 use constant {
 	PLAINTEXT => 0,
 	BLOCKS    => 1,
+	FORMAT    => 2,
 };
 
 use overload (
-
-#	q{@{}}   => sub { ${$_[0]->[BLOCKS]} },
-#	q{@{}}   => sub { ( $_[0]->[BLOCKS] ) },
-#	q{@{}}   => sub { $_[0]->[BLOCKS] },
-#	q{0+}    => sub { 0+$_[0]->[BLOCKS] },
-	q{""}    => sub { $_[0]->_compose },
+	q{""}    => '_compose',
 	fallback => 1,
 );
 
@@ -79,16 +75,26 @@ and serializes in normalized format.
 
 Options can be set as an argument to the 'use' statement.
 
-    use String::Copyright { threshold_after => 5 };
-
 =head2 threshold, threshold_before, threshold_after
 
+    use String::Copyright { threshold_after => 5 };
+
 Stop parsing after this many lines whithout copyright information,
 before or after having found any copyright information at all.
 C<threshold> sets both C<threshold_before> and C<threshold_after>.
 
 By default unset: All lines are parsed.
 
+=head2 format( \&sub )
+
+    use String::Copyright { format => \&NGU_style } };
+
+    sub GNU_style {
+        my ( $years, $owners ) = @_;
+
+        return 'Copyright (C) ' . join '  ', $years || '', $owners || '';
+    }
+
 =head1 FUNCTIONS
 
 Exports one function: C<copyright>.
@@ -109,6 +115,8 @@ my $comma_re
 my $dash_re
 	= qr/$blank_re*[-˗‐‑‒–—―⁃−﹣－]$blank_or_break_re*/;
 my $owner_initial_re = qr/[^\s!\"#$%&'()*+,.\/:;<=>?@[\\\]^_`{|}~]/;
+my $boilerplate_re
+	= qr/${comma_re}All$blank_re+Rights$blank_re+Reserved[.!]?/i;
 
 # TODO: test if \K or non-backref beneficial on perl >= 5.10
 #my $comma_tidy_re = qr/$year_re\K$comma_re(?=$year_re)/;
@@ -196,20 +204,22 @@ sub _generate_copyright
 			$years =~ s/$comma_tidy_re/$comma_tidied/g;
 			$years =~ s/$years_tidy_re/-$^N/g;
 			$owners =~ s/\s{2,}/ /g;
-
-			my $copyright_match
-				= ( length $years and length $owners )
-				? $years . ' ' . $owners
-				: $years . $owners;
+			$owners =~ s/$boilerplate_re?$//g;
 
 # split owner into owner_id and owner
 
-			push @block, $copyright_match;
+			push @block, [ $years || undef, $owners || undef ];
 		}
 
 # TODO: save $skipped_lines to indicate how dirty parsing was
 
-		bless [ $copyright, \@block ], __PACKAGE__;
+		my $ext_format = $globals->{format};
+		my $format
+			= $globals->{format}
+			? sub { &$ext_format( $_->[0], $_->[1] ) }
+			: sub { join ' ', '©', $_->[0] || (), $_->[1] || () };
+
+		bless [ $copyright, \@block, $format ], __PACKAGE__;
 		}
 }
 
@@ -231,8 +241,6 @@ sub new
 	bless [ undef, \@data ], __PACKAGE__;
 }
 
-sub blocks { $_[0]->[BLOCKS] }
-
 sub normalize
 {
 	my ( $self, @opts ) = @_;
@@ -244,7 +252,8 @@ sub normalize
 
 sub _compose
 {
-	join "\n", map { '© ' . $_ } @{ $_[0]->[BLOCKS] };
+	my $format = $_[0]->[FORMAT];
+	join "\n", map {&$format} @{ $_[0]->[BLOCKS] };
 }
 
 sub is_normalized { !defined $_[0]->[PLAINTEXT] }
